from datetime import datetime, timedelta
from timetable import load_timetable, sum_timetable, datetime_range
# >>>
start, end = datetime(2015, 1, 1), datetime(2015, 2, 1)
days = list(datetime_range(start, end, timedelta(days=1)))
# >>>
work = sum_timetable(load_timetable({'Work': open('data/work.ics', 'rb')},
        clip_start=start, clip_end=end), days)
duty = sum_timetable(load_timetable({'Duty': open('data/duty.ics', 'rb')},
        clip_start=start, clip_end=end), days)

# We start by loading each calendar in two timetables and summing them up on
# each day.

duty_series = [max(w - h - v, 0) / 3600
        for w, h, v in zip(duty['Duty'], duty['Holiday'], duty['Vacation'])]

# Now we need to subtract the holiday and vacation time from the duty time.

import numpy as np
import matplotlib.pyplot as plt
from matplotlib.patches import Patch
from matplotlib.cm import ScalarMappable
# >>>
fig = plt.figure()
ax = fig.add_subplot(1, 1, 1)
# >>>
# Draw a stackplot with custom colors and legend handles.
colormap = ScalarMappable(cmap='Paired')
colormap.set_clim(0, len(work))
data, colors, handles, labels = [], [], [], []
for idx, name in enumerate(sorted(work)):
    color = colormap.to_rgba(idx)
    data.append(np.cumsum(work[name]) / 3600)
    colors.append(color)
    handles.append(Patch(color=color))
    labels.append(name)
ax.stackplot(days, data, colors=colors)
# [...]

# Draw the stacked cumulative plot as above.

handles.extend(ax.plot(days, np.cumsum(duty_series), lw=2, ls='--'))
labels.append('Duty')

# Add a line for the duty time series.

fig.autofmt_xdate()
ax.set_ylabel('Hours')
# <...>
ax.legend(handles, labels, loc='upper left')
# <...>
# >>>
plt.show() # doctest: +SKIP
